==> znuny_6.5.1.orig.tar.gz: Znuny-rel-6_5_1/README.md <==
<a href="https://www.znuny.org"><img align="center" src="https://github.com/znuny/Znuny/blob/rel-6_5/var/httpd/htdocs/skins/Agent/default/img/logo.png"></a>

<p align="center">
    <a href="https://download.znuny.org/releases/znuny-latest.tar.gz"><img src="https://img.shields.io/github/v/tag/znuny/Znuny?sort=semver&label=latest%20release&color=ff9b00"></a>
    <br>
    <a href="https://github.com/znuny/Znuny/actions"><img src="https://img.shields.io/github/actions/workflow/status/znuny/Znuny/ci.yaml?label=CI"></a>
    <a href="https://github.com/znuny/Znuny/actions"><img src="https://badge.proxy.znuny.com/Znuny/rel-6_5"></a>
    <a href="https://translations.znuny.org/engage/znuny/"><img src="https://translations.znuny.org/widgets/znuny/-/znuny/svg-badge.svg" alt="Translation status"></a>
    <br>
    <a href="https://github.com/znuny/Znuny/issues"><img src="https://img.shields.io/github/issues-raw/znuny/Znuny?"></a>
    <a href="https://github.com/znuny/Znuny/issues?q=is%3Aissue+is%3Aclosed"><img src="https://img.shields.io/github/issues-closed-raw/znuny/Znuny?color=#44CC44"></a>
    <a href="https://github.com/znuny/Znuny/pulls"><img src="https://img.shields.io/github/issues-pr-raw/znuny/Znuny?"></a>
    <a href="https://github.com/znuny/Znuny/pulls?q=is%3Apr+is%3Aclosed"><img src="https://img.shields.io/github/issues-pr-closed-raw/znuny/Znuny?color=brightgreen"></a>
    <br>
    <a href="https://github.com/znuny/Znuny"><img src="https://img.shields.io/github/languages/count/znuny/Znuny?style=flat&label=language&color=brightgreen"></a>
    <a href="https://github.com/znuny/Znuny/graphs/contributors"><img src="https://img.shields.io/github/contributors/znuny/Znuny?"></a>
    <a href="https://discord.gg/XTud3WWZTs"><img src="https://img.shields.io/discord/836533233885773825?style=flat"></a>
</p>
<hr>

Znuny
=======
Znuny is a continuation of the ((OTRS)) Community Edition (version 6.0.30) which was declared end of life (EOL) at the end of December 2020.

The primary goal for this project is to provide a maintained and stable version of the well known ticket system and improve it with new features.

The second goal is to reestablish a connection to the community.

License
=======
The project is distributed under the GNU General Public License (GPL v3) - see the accompanying [COPYING](COPYING) file for general license information.
If you need more details you can have a look [here](https://snyk.io/learn/what-is-gpl-license-gplv3-explained/).

Documentation
=============
You can find documentation [here](https://doc.znuny.org/).
The source code of Znuny is publicly available on [GitHub](https://github.com/znuny/znuny).

You want to get in touch?
- [Project website](https://www.znuny.org)
- [Community forum](https://community.znuny.org)
- [Discord Server](https://discord.gg/XTud3WWZTs)
- [Commercial services](https://www.znuny.com)

Software requirements
=====================
Operating system
- Linux (Debian or Red Hat preferred)
- Perl 5.16.0 or higher

Web server
- Apache 2 + mod_perl2 or higher (recommended)
- Web server with CGI support (CGI is not recommended)

Databases
- MySQL 5.0 or higher
- MariaDB
- PostgreSQL 9.2 or higher
- Oracle 10g or higher

Browsers
- These browsers are NOT supported:
  - Internet Explorer before version 11
  - Firefox before version 31
  - Safari before version 6

Vendor
=======
This project is mainly funded by Znuny GmbH, Berlin.
If you need professional support or consulting, feel free to contact us.

[Znuny Website](https://www.znuny.com)

==> znuny_6.5.18.orig.tar.gz: Znuny-rel-6_5_18/README.md <==
<a href="https://www.znuny.org"><img align="center" src="https://github.com/znuny/Znuny/blob/rel-6_5/var/httpd/htdocs/skins/Agent/default/img/logo.png"></a>

<p align="center">
    <a href="https://download.znuny.org/releases/znuny-latest-6.5.tar.gz"><img src="https://img.shields.io/github/v/tag/znuny/Znuny?filter=rel-6_5_*&label=latest%20release&color=ff9b00"></a>
    <br>
    <a href="https://github.com/znuny/Znuny/actions"><img src="https://img.shields.io/github/actions/workflow/status/znuny/Znuny/ci.yaml?label=CI"></a>
    <a href="https://github.com/znuny/Znuny/actions"><img src="https://badge.proxy.znuny.com/Znuny/rel-6_5"></a>
    <a href="https://translations.znuny.org/engage/znuny/"><img src="https://translations.znuny.org/widgets/znuny/-/znuny/svg-badge.svg" alt="Translation status"></a>
    <br>
    <a href="https://github.com/znuny/Znuny/issues"><img src="https://img.shields.io/github/issues-raw/znuny/Znuny?"></a>
    <a href="https://github.com/znuny/Znuny/issues?q=is%3Aissue+is%3Aclosed"><img src="https://img.shields.io/github/issues-closed-raw/znuny/Znuny?color=#44CC44"></a>
    <a href="https://github.com/znuny/Znuny/pulls"><img src="https://img.shields.io/github/issues-pr-raw/znuny/Znuny?"></a>
    <a href="https://github.com/znuny/Znuny/pulls?q=is%3Apr+is%3Aclosed"><img src="https://img.shields.io/github/issues-pr-closed-raw/znuny/Znuny?color=brightgreen"></a>
    <br>
    <a href="https://github.com/znuny/Znuny"><img src="https://img.shields.io/github/languages/count/znuny/Znuny?style=flat&label=languages&color=brightgreen"></a>
    <a href="https://github.com/znuny/Znuny/graphs/contributors"><img src="https://img.shields.io/github/contributors/znuny/Znuny?"></a>
    <a href="https://discord.gg/XTud3WWZTs"><img src="https://img.shields.io/discord/836533233885773825?style=flat"></a>
</p>
<hr>

Znuny
=======
Znuny is a continuation of the ((OTRS)) Community Edition (version 6.0.30) which was declared end of life (EOL) at the end of December 2020.

The primary goal for this project is to provide a maintained and stable version of the well known ticket system and improve it with new features.

The second goal is to reestablish a connection to the community.

License
=======
The project is distributed under the GNU General Public License (GPL v3) - see the accompanying [COPYING](COPYING) file for general license information.
If you need more details you can have a look [here](https://snyk.io/learn/what-is-gpl-license-gplv3-explained/).

Documentation
=============
You can find documentation [here](https://doc.znuny.org/).
The source code of Znuny is publicly available on [GitHub](https://github.com/znuny/znuny).

You want to get in touch?
- [Project website](https://www.znuny.org)
- [Community forum](https://community.znuny.org)
- [Discord Server](https://discord.gg/XTud3WWZTs)
- [Commercial services](https://www.znuny.com)

Software requirements
=====================
Operating system
- Linux (Debian or Red Hat preferred)
- Perl 5.16.0 or higher

Web server
- Apache 2 + mod_perl2 or higher (recommended)
- Web server with CGI support (CGI is not recommended)

Databases
- MySQL 5.0 or higher
- MariaDB
- PostgreSQL 9.2 or higher
- Oracle 10g or higher

Browsers
- These browsers are NOT supported:
  - Internet Explorer before version 11
  - Firefox before version 31
  - Safari before version 6

Vendor
=======
This project is mainly funded by Znuny GmbH, Berlin.
If you need professional support or consulting, feel free to contact us.

[Znuny Website](https://www.znuny.com)
